#!/bin/sh

# usb installer...
#
# Written By: Stephen Parker <stephen.parker@braintree.com.au>
#
# Copyright (c) 2002, Braintree Communications Pty Ltd. All rights reserved.
#


# check if kernal has usb support...
echo -n "Checking Kernel USB support..."
if [ ! -d "/proc/bus/usb" -a `lsmod | grep -c "^usbcore"` == 1 ]; then
	echo "Error:  No kernel support for usb."
	exit 1
fi

# check support for ACM
modprobe acm
if [ `lsmod | grep -c "^acm"` == 0 ]; then
	echo "ERROR: No support for acm."
	exit 1
fi
rmmod acm
echo "done."

#
# create nodes if needed...
#

# check directory exists and create if needed
if [ ! -d "/dev/usb" ]; then
	echo -n "creating directory '/dev/usb' for these new usb device files..."
	mkdir "/dev/usb"
	echo "done."
fi

# create device files.
if [ ! -c "/dev/usb/ttyACM0" ]; then
	echo -n "creating /dev/usb/ttyACM0..."
	mknod /dev/usb/ttyACM0 c 166 0
	chmod 600 /dev/usb/ttyACM0
	echo "done."
else
	echo "WARNING:  Device file '/dev/usb/ttyACM0' already exists"
fi
if [ ! -c "/dev/usb/ttyACM1" ]; then
	echo -n "creating /dev/usb/ttyACM1..."
	mknod /dev/usb/ttyACM1 c 166 1
	chmod 600 /dev/usb/ttyACM1
	echo "done."
else
	echo "WARNING:  Device file '/dev/usb/ttyACM1' already exists"
fi
if [ ! -c "/dev/usb/ttyACM2" ]; then
	echo -n "creating /dev/usbttyACM2..."
	mknod /dev/usb/ttyACM2 c 166 2
	chmod 600 /dev/usb/ttyACM2
	echo "done."
else
	echo "WARNING:  Device file '/dev/usb/ttyACM2' already exists"
fi
if [ ! -c "/dev/usb/ttyACM3" ]; then
	echo -n "creating /dev/usb/ttyACM3..."
	mknod /dev/usb/ttyACM3 c 166 3
	chmod 600 /dev/usb/ttyACM3
	echo "done."
else
	echo "WARNING:  Device file '/dev/usb/ttyACM3' already exists"
fi

# exit cleanly
echo "Installation completed successfully."
exit 0;

